@@ -20,6 +20,7 @@ COMMENT=Dictionary client (RFC-2229) for [X]Emacs
 MAINTAINER=cheusov@tut.by
 CATEGORIES=textproc editors
 PKGNAME=dictem-0.82
+ALLSRCFILES=   ccc1-subdir/ccc-1.1.tgz ccc1-subdir/ccc-1.1.patch1   ccc1-subdir/ccc-1.1.patch2   
 
 BUILD_DEPENDS= libtool-base>=1.5.18nb5:../../devel/libtool-base gmake>=3.81:../../devel/gmake checkperms>=1.1:../../sysutils/checkperms
 PKGNAME=dict-server-1.10.11nb2
@@ -61,6 +62,7 @@ COMMENT=Dictionary client (RFC-2229) for [X]Emacs
 MAINTAINER=cheusov@tut.by
 CATEGORIES=textproc editors
 PKGNAME=dictem-0.82
+ALLSRCFILES=   ccc1-subdir/ccc-1.1.tgz ccc1-subdir/ccc-1.1.patch1   ccc1-subdir/ccc-1.1.patch2   
 
 BUILD_DEPENDS= libtool-base>=1.5.18nb5:../../devel/libtool-base gmake>=3.81:../../devel/gmake checkperms>=1.1:../../sysutils/checkperms
 PKGNAME=dict-server-1.10.11nb2
@@ -102,6 +104,7 @@ COMMENT=DISTributed Bulk Build tool for pkgsrc
 MAINTAINER=cheusov@tut.by
 CATEGORIES=pkgtools
 EXFIELD=XVALUE1
+ALLSRCFILES=   ccc-subdir/ccc-0.0.tgz ccc-subdir/ccc-0.0.patch1 ccc-subdir/ccc-0.0.patch2
 
 PKGPATH=textproc/dictem
 DEPENDS=dict-client>=1.9.14:../../textproc/dict-client emacs>=22:../../editors/emacs  emacs>=22:../../editors/emacs
@@ -112,6 +115,7 @@ COMMENT=Dictionary client (RFC-2229) for [X]Emacs
 MAINTAINER=cheusov@tut.by
 CATEGORIES=textproc editors
 PKGNAME=dictem-0.82
+ALLSRCFILES=   ccc1-subdir/ccc-1.1.tgz ccc1-subdir/ccc-1.1.patch1   ccc1-subdir/ccc-1.1.patch2   
 
 BUILD_DEPENDS= libtool-base>=1.5.18nb5:../../devel/libtool-base gmake>=3.81:../../devel/gmake checkperms>=1.1:../../sysutils/checkperms
 PKGNAME=dict-server-1.10.11nb2
@@ -287,6 +291,138 @@ PKGNAME=ap2-vhost-ldap-1.2.0nb1
 
 '
 
+runtest pkg_grep_summary -f PKGNAME -v -t nonempty EXFIELD < src_summary.txt | \
+cmp 'pkg_grep_summary #7.1' \
+'PKGNAME=dictem-0.82
+
+PKGNAME=pkg_online-0.5.0nb2
+
+PKGNAME=dict-server-1.10.11nb2
+
+PKGNAME=pkg_online-server-0.5.0
+
+PKGNAME=dict-client-1.9.15nb2
+
+PKGNAME=pkg_online-client-0.5.0
+
+PKGNAME=libmaa-1.0.1nb1
+
+PKGNAME=gmake-3.81
+
+PKGNAME=paexec-0.10.0nb1
+
+PKGNAME=libtool-base-1.5.24nb6
+
+PKGNAME=runawk-0.14.3
+
+PKGNAME=emacs-22.1nb6
+
+PKGNAME=pkg_summary-utils-0.18.1
+
+PKGNAME=libungif-4.1.4nb1
+
+PKGNAME=tiff-3.8.2nb4
+
+PKGNAME=x11-links-0.38
+
+PKGNAME=perl-5.8.8nb8
+
+PKGNAME=libltdl-1.5.24
+
+PKGNAME=dict-client-1.10.11nb2
+
+PKGNAME=pipestatus-0.4.0
+
+PKGNAME=awk-pkgsrc-dewey-0.5.6
+
+PKGNAME=png-1.2.32beta01
+
+PKGNAME=netcat-1.10nb2
+
+PKGNAME=pkg-config-0.23
+
+PKGNAME=jpeg-6bnb4
+
+PKGNAME=ap22-vhost-ldap-1.2.0nb1
+
+PKGNAME=ap2-vhost-ldap-1.2.0nb1
+
+'
+
+runtest pkg_grep_summary -f PKGNAME -e EXFIELD < src_summary.txt | \
+cmp 'pkg_grep_summary #7.2' \
+'PKGNAME=dictem-0.82
+
+PKGNAME=pkg_online-0.5.0nb2
+
+PKGNAME=dict-server-1.10.11nb2
+
+PKGNAME=pkg_online-server-0.5.0
+
+PKGNAME=dict-client-1.9.15nb2
+
+PKGNAME=pkg_online-client-0.5.0
+
+PKGNAME=libmaa-1.0.1nb1
+
+PKGNAME=gmake-3.81
+
+PKGNAME=paexec-0.10.0nb1
+
+PKGNAME=libtool-base-1.5.24nb6
+
+PKGNAME=runawk-0.14.3
+
+PKGNAME=emacs-22.1nb6
+
+PKGNAME=pkg_summary-utils-0.18.1
+
+PKGNAME=libungif-4.1.4nb1
+
+PKGNAME=tiff-3.8.2nb4
+
+PKGNAME=x11-links-0.38
+
+PKGNAME=perl-5.8.8nb8
+
+PKGNAME=libltdl-1.5.24
+
+PKGNAME=dict-client-1.10.11nb2
+
+PKGNAME=pipestatus-0.4.0
+
+PKGNAME=awk-pkgsrc-dewey-0.5.6
+
+PKGNAME=png-1.2.32beta01
+
+PKGNAME=netcat-1.10nb2
+
+PKGNAME=pkg-config-0.23
+
+PKGNAME=jpeg-6bnb4
+
+PKGNAME=ap22-vhost-ldap-1.2.0nb1
+
+PKGNAME=ap2-vhost-ldap-1.2.0nb1
+
+'
+
+runtest pkg_grep_summary -f PKGNAME -E EXFIELD < src_summary.txt | \
+cmp 'pkg_grep_summary #7.3' \
+'PKGNAME=distbb-0.22.0
+
+PKGNAME=checkperms-1.10
+
+'
+
+runtest pkg_grep_summary -f PKGNAME -ve EXFIELD < src_summary.txt | \
+cmp 'pkg_grep_summary #7.4' \
+'PKGNAME=distbb-0.22.0
+
+PKGNAME=checkperms-1.10
+
+'
+
 runtest pkg_grep_summary -m MAINTAINER 'cheusov|vle@gmx.net' < src_summary.txt |
     grep -E 'PKGNAME|PKGPATH|^$|MAINTAINER|COMMENT' |
 cmp 'pkg_grep_summary #8' \
@@ -434,6 +570,7 @@ COMMENT=DISTributed Bulk Build tool for pkgsrc
 MAINTAINER=cheusov@tut.by
 CATEGORIES=pkgtools
 EXFIELD=XVALUE1
+ALLSRCFILES=   ccc-subdir/ccc-0.0.tgz ccc-subdir/ccc-0.0.patch1 ccc-subdir/ccc-0.0.patch2
 
 BUILD_DEPENDS= libtool-base>=1.5.18nb5:../../devel/libtool-base gmake>=3.81:../../devel/gmake checkperms>=1.1:../../sysutils/checkperms
 PKGNAME=dict-server-1.10.11nb2
@@ -472,6 +609,7 @@ COMMENT=DISTributed Bulk Build tool for pkgsrc
 MAINTAINER=cheusov@tut.by
 CATEGORIES=pkgtools
 EXFIELD=XVALUE1
+ALLSRCFILES=   ccc-subdir/ccc-0.0.tgz ccc-subdir/ccc-0.0.patch1 ccc-subdir/ccc-0.0.patch2
 
 BUILD_DEPENDS= libtool-base>=1.5.18nb5:../../devel/libtool-base gmake>=3.81:../../devel/gmake checkperms>=1.1:../../sysutils/checkperms
 PKGNAME=dict-server-1.10.11nb2
@@ -510,6 +648,7 @@ COMMENT=DISTributed Bulk Build tool for pkgsrc
 MAINTAINER=cheusov@tut.by
 CATEGORIES=pkgtools
 EXFIELD=XVALUE1
+ALLSRCFILES=   ccc-subdir/ccc-0.0.tgz ccc-subdir/ccc-0.0.patch1 ccc-subdir/ccc-0.0.patch2
 
 BUILD_DEPENDS= libtool-base>=1.5.18nb5:../../devel/libtool-base gmake>=3.81:../../devel/gmake checkperms>=1.1:../../sysutils/checkperms
 PKGNAME=dict-server-1.10.11nb2
@@ -541,6 +680,7 @@ COMMENT=DISTributed Bulk Build tool for pkgsrc
 MAINTAINER=cheusov@tut.by
 CATEGORIES=pkgtools
 EXFIELD=XVALUE1
+ALLSRCFILES=   ccc-subdir/ccc-0.0.tgz ccc-subdir/ccc-0.0.patch1 ccc-subdir/ccc-0.0.patch2
 
 BUILD_DEPENDS= libtool-base>=1.5.18nb5:../../devel/libtool-base gmake>=3.81:../../devel/gmake checkperms>=1.1:../../sysutils/checkperms
 PKGNAME=dict-server-1.10.11nb2
@@ -579,6 +719,7 @@ COMMENT=DISTributed Bulk Build tool for pkgsrc
 MAINTAINER=cheusov@tut.by
 CATEGORIES=pkgtools
 EXFIELD=XVALUE1
+ALLSRCFILES=   ccc-subdir/ccc-0.0.tgz ccc-subdir/ccc-0.0.patch1 ccc-subdir/ccc-0.0.patch2
 
 BUILD_DEPENDS= libtool-base>=1.5.18nb5:../../devel/libtool-base gmake>=3.81:../../devel/gmake checkperms>=1.1:../../sysutils/checkperms
 PKGNAME=dict-server-1.10.11nb2
@@ -611,6 +752,7 @@ COMMENT=DISTributed Bulk Build tool for pkgsrc
 MAINTAINER=cheusov@tut.by
 CATEGORIES=pkgtools
 EXFIELD=XVALUE1
+ALLSRCFILES=   ccc-subdir/ccc-0.0.tgz ccc-subdir/ccc-0.0.patch1 ccc-subdir/ccc-0.0.patch2
 
 PKGNAME=png-1.2.32beta01
 PKGPATH=graphics/png
@@ -998,6 +1140,7 @@ COMMENT=Dictionary client (RFC-2229) for [X]Emacs
 MAINTAINER=cheusov@tut.by
 CATEGORIES=textproc editors
 PKGNAME=dictem-0.82
+ALLSRCFILES=   ccc1-subdir/ccc-1.1.tgz ccc1-subdir/ccc-1.1.patch1   ccc1-subdir/ccc-1.1.patch2   
 
 PKGNAME=dict-client-1.9.15nb2
 PKGPATH=textproc/dict-client
@@ -1031,6 +1174,7 @@ COMMENT=Dictionary client (RFC-2229) for [X]Emacs
 MAINTAINER=cheusov@tut.by
 CATEGORIES=textproc editors
 PKGNAME=dictem-0.82
+ALLSRCFILES=   ccc1-subdir/ccc-1.1.tgz ccc1-subdir/ccc-1.1.patch1   ccc1-subdir/ccc-1.1.patch2   
 
 PKGNAME=dict-client-1.9.15nb2
 PKGPATH=textproc/dict-client
@@ -1220,10 +1364,10 @@ exit status: 2
 
 runtest pkg_grep_summary -T |
 cmp 'pkg_grep_summary #53' \
-'exact prefix suffix substring word first last re strfile strlist awk empty kw
+'exact prefix suffix substring word first last re strfile strlist awk empty nonempty kw
 '
 
-runtest pkg_grep_summary -T -T |
+runtest pkg_grep_summary -TT |
 cmp 'pkg_grep_summary #54' \
 'exact	Match exactly
 prefix	Match prefixes
@@ -1237,6 +1381,7 @@ strfile	Match the words from file
 strlist	Match the specified words
 awk	Match using AWK expression
 empty	Match an empty string
+nonempty	Match any non-empty string
 kw	"keyword" match
 '
 
