@@ -1,3 +1,9 @@
+: ${PKGSRCDIR:=/usr/pkgsrc}
+
+if ! test -d PKGSRCDIR; then
+    echo "Directory $PKGSRCDIR does not exit, skipping tests for pkg_src_summary" 1>&2
+else
+
 grep_pss_stderr (){
     grep -E 'Bad package| ----------' "$@"
 }
@@ -13,9 +19,13 @@ cmp 'pkg_src_summary #27.1' \
 'PKGNAME=sqlite3-X
 PKGPATH=databases/sqlite3
 
+PKGNAME=cwrappers-X
+PKGPATH=pkgtools/cwrappers
+
 '
 
 pkg_src_summary -f PKGNAME,PKGPATH -At databases/sqlite3 |
+pkg_grep_summary -v -s PKGBASE gmake |
 pkg_grep_summary -v -t strlist PKGBASE 'readline ncurses pkg_install-info nbpatch' |
 hide_distfile_size | normalize_version | grep -vE 'DEPENDS=' |
 cmp 'pkg_src_summary #27.2' \
@@ -25,12 +35,12 @@ PKGPATH=databases/sqlite3
 PKGNAME=checkperms-X
 PKGPATH=sysutils/checkperms
 
-PKGNAME=gmake-X
-PKGPATH=devel/gmake
-
 PKGNAME=libtool-base-X
 PKGPATH=devel/libtool-base
 
+PKGNAME=cwrappers-X
+PKGPATH=pkgtools/cwrappers
+
 '
 
 #pkg_src_summary -f PKGNAME,PKGPATH -Atb databases/sqlite3 |
@@ -80,73 +90,59 @@ PLIST
 TOOL_DEPENDS
 '
 
-# # FIXME and remove RUBY_VERSION_REQD=193,
-# pkg_src_summary -m -f PKGNAME,PKGPATH \
-#     devel/subversion:RUBY_VERSION_REQD=193,PKG_APACHE=apache2 \
-#     devel/subversion:RUBY_VERSION_REQD=193,PKG_APACHE=apache2,PYTHON_VERSION_REQD=27 |
-# normalize_version |
-# cmp 'pkg_src_summary #24.1' \
-# 'ASSIGNMENTS=PKG_APACHE=apache2
-# PKGNAME=subversion-X
-# PKGPATH=devel/subversion
-
-# ASSIGNMENTS=PKG_APACHE=apache2,PYTHON_VERSION_REQD=26
-# PKGNAME=subversion-X
-# PKGPATH=devel/subversion
-
-# '
-
 pkg_src_summary -m -f PKGNAME,PKGPATH \
-    devel/subversion:PYTHON_VERSION_REQD=27,RUBY_VERSION_REQD=18 |
-normalize_version |
-cmp 'pkg_src_summary #23.10' \
-'ASSIGNMENTS=RUBY_VERSION_REQD=18
-PKGNAME=subversion-X
-PKGPATH=devel/subversion
-
-ASSIGNMENTS=RUBY_VERSION_REQD=18,PKG_APACHE=apache24
-PKGNAME=subversion-X
-PKGPATH=devel/subversion
-
-'
-
-pkg_src_summary -m -f PKGNAME,PKGPATH \
-    devel/subversion:PYTHON_VERSION_REQD=26,RUBY_VERSION_REQD=18 |
-normalize_version |
-cmp 'pkg_src_summary #23.9' \
-'ASSIGNMENTS=PYTHON_VERSION_REQD=26,RUBY_VERSION_REQD=18
-PKGNAME=subversion-X
-PKGPATH=devel/subversion
-
-ASSIGNMENTS=PYTHON_VERSION_REQD=26,RUBY_VERSION_REQD=18,PKG_APACHE=apache24
-PKGNAME=subversion-X
-PKGPATH=devel/subversion
-
-'
-
-pkg_src_summary -m -f PKGNAME,PKGPATH \
-    devel/subversion:PYTHON_VERSION_REQD=27,RUBY_VERSION_REQD=193 |
+    devel/subversion:PYTHON_VERSION_REQD=27 |
 normalize_version |
 cmp 'pkg_src_summary #23.8' \
-'ASSIGNMENTS=RUBY_VERSION_REQD=193
+'PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=RUBY_VERSION_REQD=23
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
-ASSIGNMENTS=RUBY_VERSION_REQD=193,PKG_APACHE=apache24
+ASSIGNMENTS=RUBY_VERSION_REQD=21
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PKG_APACHE=apache24
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PKG_APACHE=apache24,RUBY_VERSION_REQD=23
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PKG_APACHE=apache24,RUBY_VERSION_REQD=21
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
 '
 
 pkg_src_summary -m -f PKGNAME,PKGPATH \
-    devel/subversion:PYTHON_VERSION_REQD=27,RUBY_VERSION_REQD=193 |
+    devel/subversion:PYTHON_VERSION_REQD=27 |
 normalize_version |
 cmp 'pkg_src_summary #23.7' \
-'ASSIGNMENTS=RUBY_VERSION_REQD=193
+'PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=RUBY_VERSION_REQD=23
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
-ASSIGNMENTS=RUBY_VERSION_REQD=193,PKG_APACHE=apache24
+ASSIGNMENTS=RUBY_VERSION_REQD=21
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PKG_APACHE=apache24
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PKG_APACHE=apache24,RUBY_VERSION_REQD=23
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PKG_APACHE=apache24,RUBY_VERSION_REQD=21
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
@@ -158,11 +154,7 @@ cmp 'pkg_src_summary #23.6' \
 'PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
-ASSIGNMENTS=RUBY_VERSION_REQD=193
-PKGNAME=subversion-X
-PKGPATH=devel/subversion
-
-ASSIGNMENTS=RUBY_VERSION_REQD=18
+ASSIGNMENTS=RUBY_VERSION_REQD=23
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
@@ -174,11 +166,7 @@ ASSIGNMENTS=PKG_APACHE=apache24
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
-ASSIGNMENTS=PKG_APACHE=apache24,RUBY_VERSION_REQD=193
-PKGNAME=subversion-X
-PKGPATH=devel/subversion
-
-ASSIGNMENTS=PKG_APACHE=apache24,RUBY_VERSION_REQD=18
+ASSIGNMENTS=PKG_APACHE=apache24,RUBY_VERSION_REQD=23
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
@@ -189,96 +177,181 @@ PKGPATH=devel/subversion
 '
 
 pkg_src_summary -m -f PKGNAME,PKGPATH \
-    devel/subversion:RUBY_VERSION_REQD=193,PKG_APACHE=apache22 |
+    devel/subversion:PKG_APACHE=apache22 |
 normalize_version |
 cmp 'pkg_src_summary #23.5' \
-'ASSIGNMENTS=RUBY_VERSION_REQD=193,PYTHON_VERSION_REQD=34
+'ASSIGNMENTS=PYTHON_VERSION_REQD=36
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
-ASSIGNMENTS=RUBY_VERSION_REQD=193,PYTHON_VERSION_REQD=33
+ASSIGNMENTS=PYTHON_VERSION_REQD=36,RUBY_VERSION_REQD=23
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
-ASSIGNMENTS=RUBY_VERSION_REQD=193
+ASSIGNMENTS=PYTHON_VERSION_REQD=36,RUBY_VERSION_REQD=21
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
-ASSIGNMENTS=RUBY_VERSION_REQD=193,PYTHON_VERSION_REQD=26
+ASSIGNMENTS=PYTHON_VERSION_REQD=35
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PYTHON_VERSION_REQD=35,RUBY_VERSION_REQD=23
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PYTHON_VERSION_REQD=35,RUBY_VERSION_REQD=21
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PYTHON_VERSION_REQD=34
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PYTHON_VERSION_REQD=34,RUBY_VERSION_REQD=23
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PYTHON_VERSION_REQD=34,RUBY_VERSION_REQD=21
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=RUBY_VERSION_REQD=23
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=RUBY_VERSION_REQD=21
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
 '
 
-pkg_src_summary -m -f PKGNAME,PKGPATH devel/subversion:PYTHON_VERSION_REQD=26 |
+pkg_src_summary -m -f PKGNAME,PKGPATH devel/subversion:PYTHON_VERSION_REQD=27 |
 normalize_version |
 cmp 'pkg_src_summary #23.4' \
-'ASSIGNMENTS=PYTHON_VERSION_REQD=26
+'PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=RUBY_VERSION_REQD=23
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
-ASSIGNMENTS=PYTHON_VERSION_REQD=26,RUBY_VERSION_REQD=193
+ASSIGNMENTS=RUBY_VERSION_REQD=21
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
-ASSIGNMENTS=PYTHON_VERSION_REQD=26,RUBY_VERSION_REQD=18
+ASSIGNMENTS=PKG_APACHE=apache24
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
-ASSIGNMENTS=PYTHON_VERSION_REQD=26,RUBY_VERSION_REQD=21
+ASSIGNMENTS=PKG_APACHE=apache24,RUBY_VERSION_REQD=23
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
-ASSIGNMENTS=PYTHON_VERSION_REQD=26,PKG_APACHE=apache24
-PKGNAME=subversion-X
-PKGPATH=devel/subversion
-
-ASSIGNMENTS=PYTHON_VERSION_REQD=26,PKG_APACHE=apache24,RUBY_VERSION_REQD=193
-PKGNAME=subversion-X
-PKGPATH=devel/subversion
-
-ASSIGNMENTS=PYTHON_VERSION_REQD=26,PKG_APACHE=apache24,RUBY_VERSION_REQD=18
-PKGNAME=subversion-X
-PKGPATH=devel/subversion
-
-ASSIGNMENTS=PYTHON_VERSION_REQD=26,PKG_APACHE=apache24,RUBY_VERSION_REQD=21
+ASSIGNMENTS=PKG_APACHE=apache24,RUBY_VERSION_REQD=21
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
 '
 
-pkg_src_summary -m -f PKGNAME,PKGPATH devel/subversion:RUBY_VERSION_REQD=193 |
+pkg_src_summary -m -f PKGNAME,PKGPATH devel/subversion |
 normalize_version |
 cmp 'pkg_src_summary #23.3' \
-'ASSIGNMENTS=RUBY_VERSION_REQD=193,PYTHON_VERSION_REQD=34
+'ASSIGNMENTS=PYTHON_VERSION_REQD=36
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
-ASSIGNMENTS=RUBY_VERSION_REQD=193,PYTHON_VERSION_REQD=33
+ASSIGNMENTS=PYTHON_VERSION_REQD=36,RUBY_VERSION_REQD=23
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
-ASSIGNMENTS=RUBY_VERSION_REQD=193
+ASSIGNMENTS=PYTHON_VERSION_REQD=36,RUBY_VERSION_REQD=21
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
-ASSIGNMENTS=RUBY_VERSION_REQD=193,PYTHON_VERSION_REQD=26
+ASSIGNMENTS=PYTHON_VERSION_REQD=35
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
-ASSIGNMENTS=RUBY_VERSION_REQD=193,PKG_APACHE=apache24,PYTHON_VERSION_REQD=34
+ASSIGNMENTS=PYTHON_VERSION_REQD=35,RUBY_VERSION_REQD=23
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
-ASSIGNMENTS=RUBY_VERSION_REQD=193,PKG_APACHE=apache24,PYTHON_VERSION_REQD=33
+ASSIGNMENTS=PYTHON_VERSION_REQD=35,RUBY_VERSION_REQD=21
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
-ASSIGNMENTS=RUBY_VERSION_REQD=193,PKG_APACHE=apache24
+ASSIGNMENTS=PYTHON_VERSION_REQD=34
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
-ASSIGNMENTS=RUBY_VERSION_REQD=193,PKG_APACHE=apache24,PYTHON_VERSION_REQD=26
+ASSIGNMENTS=PYTHON_VERSION_REQD=34,RUBY_VERSION_REQD=23
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PYTHON_VERSION_REQD=34,RUBY_VERSION_REQD=21
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=RUBY_VERSION_REQD=23
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=RUBY_VERSION_REQD=21
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PKG_APACHE=apache24,PYTHON_VERSION_REQD=36
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PKG_APACHE=apache24,PYTHON_VERSION_REQD=36,RUBY_VERSION_REQD=23
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PKG_APACHE=apache24,PYTHON_VERSION_REQD=36,RUBY_VERSION_REQD=21
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PKG_APACHE=apache24,PYTHON_VERSION_REQD=35
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PKG_APACHE=apache24,PYTHON_VERSION_REQD=35,RUBY_VERSION_REQD=23
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PKG_APACHE=apache24,PYTHON_VERSION_REQD=35,RUBY_VERSION_REQD=21
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PKG_APACHE=apache24,PYTHON_VERSION_REQD=34
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PKG_APACHE=apache24,PYTHON_VERSION_REQD=34,RUBY_VERSION_REQD=23
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PKG_APACHE=apache24,PYTHON_VERSION_REQD=34,RUBY_VERSION_REQD=21
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PKG_APACHE=apache24
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PKG_APACHE=apache24,RUBY_VERSION_REQD=23
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PKG_APACHE=apache24,RUBY_VERSION_REQD=21
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
@@ -287,15 +360,35 @@ PKGPATH=devel/subversion
 pkg_src_summary -m -f PKGNAME,PKGPATH devel/subversion:PKG_APACHE=apache22 |
 normalize_version |
 cmp 'pkg_src_summary #23.2' \
-'ASSIGNMENTS=PYTHON_VERSION_REQD=34
+'ASSIGNMENTS=PYTHON_VERSION_REQD=36
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
-ASSIGNMENTS=PYTHON_VERSION_REQD=34,RUBY_VERSION_REQD=193
+ASSIGNMENTS=PYTHON_VERSION_REQD=36,RUBY_VERSION_REQD=23
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
-ASSIGNMENTS=PYTHON_VERSION_REQD=34,RUBY_VERSION_REQD=18
+ASSIGNMENTS=PYTHON_VERSION_REQD=36,RUBY_VERSION_REQD=21
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PYTHON_VERSION_REQD=35
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PYTHON_VERSION_REQD=35,RUBY_VERSION_REQD=23
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PYTHON_VERSION_REQD=35,RUBY_VERSION_REQD=21
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PYTHON_VERSION_REQD=34
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PYTHON_VERSION_REQD=34,RUBY_VERSION_REQD=23
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
@@ -303,30 +396,10 @@ ASSIGNMENTS=PYTHON_VERSION_REQD=34,RUBY_VERSION_REQD=21
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
-ASSIGNMENTS=PYTHON_VERSION_REQD=33
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
-ASSIGNMENTS=PYTHON_VERSION_REQD=33,RUBY_VERSION_REQD=193
-PKGNAME=subversion-X
-PKGPATH=devel/subversion
-
-ASSIGNMENTS=PYTHON_VERSION_REQD=33,RUBY_VERSION_REQD=18
-PKGNAME=subversion-X
-PKGPATH=devel/subversion
-
-ASSIGNMENTS=PYTHON_VERSION_REQD=33,RUBY_VERSION_REQD=21
-PKGNAME=subversion-X
-PKGPATH=devel/subversion
-
-PKGNAME=subversion-X
-PKGPATH=devel/subversion
-
-ASSIGNMENTS=RUBY_VERSION_REQD=193
-PKGNAME=subversion-X
-PKGPATH=devel/subversion
-
-ASSIGNMENTS=RUBY_VERSION_REQD=18
+ASSIGNMENTS=RUBY_VERSION_REQD=23
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
@@ -334,36 +407,40 @@ ASSIGNMENTS=RUBY_VERSION_REQD=21
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
-ASSIGNMENTS=PYTHON_VERSION_REQD=26
-PKGNAME=subversion-X
-PKGPATH=devel/subversion
-
-ASSIGNMENTS=PYTHON_VERSION_REQD=26,RUBY_VERSION_REQD=193
-PKGNAME=subversion-X
-PKGPATH=devel/subversion
-
-ASSIGNMENTS=PYTHON_VERSION_REQD=26,RUBY_VERSION_REQD=18
-PKGNAME=subversion-X
-PKGPATH=devel/subversion
-
-ASSIGNMENTS=PYTHON_VERSION_REQD=26,RUBY_VERSION_REQD=21
-PKGNAME=subversion-X
-PKGPATH=devel/subversion
-
 '
 
 pkg_src_summary -m -f PKGNAME,PKGPATH devel/subversion |
 normalize_version |
 cmp 'pkg_src_summary #23.1' \
-'ASSIGNMENTS=PYTHON_VERSION_REQD=34
+'ASSIGNMENTS=PYTHON_VERSION_REQD=36
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
-ASSIGNMENTS=PYTHON_VERSION_REQD=34,RUBY_VERSION_REQD=193
+ASSIGNMENTS=PYTHON_VERSION_REQD=36,RUBY_VERSION_REQD=23
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
-ASSIGNMENTS=PYTHON_VERSION_REQD=34,RUBY_VERSION_REQD=18
+ASSIGNMENTS=PYTHON_VERSION_REQD=36,RUBY_VERSION_REQD=21
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PYTHON_VERSION_REQD=35
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PYTHON_VERSION_REQD=35,RUBY_VERSION_REQD=23
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PYTHON_VERSION_REQD=35,RUBY_VERSION_REQD=21
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PYTHON_VERSION_REQD=34
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PYTHON_VERSION_REQD=34,RUBY_VERSION_REQD=23
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
@@ -371,30 +448,10 @@ ASSIGNMENTS=PYTHON_VERSION_REQD=34,RUBY_VERSION_REQD=21
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
-ASSIGNMENTS=PYTHON_VERSION_REQD=33
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
-ASSIGNMENTS=PYTHON_VERSION_REQD=33,RUBY_VERSION_REQD=193
-PKGNAME=subversion-X
-PKGPATH=devel/subversion
-
-ASSIGNMENTS=PYTHON_VERSION_REQD=33,RUBY_VERSION_REQD=18
-PKGNAME=subversion-X
-PKGPATH=devel/subversion
-
-ASSIGNMENTS=PYTHON_VERSION_REQD=33,RUBY_VERSION_REQD=21
-PKGNAME=subversion-X
-PKGPATH=devel/subversion
-
-PKGNAME=subversion-X
-PKGPATH=devel/subversion
-
-ASSIGNMENTS=RUBY_VERSION_REQD=193
-PKGNAME=subversion-X
-PKGPATH=devel/subversion
-
-ASSIGNMENTS=RUBY_VERSION_REQD=18
+ASSIGNMENTS=RUBY_VERSION_REQD=23
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
@@ -402,19 +459,27 @@ ASSIGNMENTS=RUBY_VERSION_REQD=21
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
-ASSIGNMENTS=PYTHON_VERSION_REQD=26
+ASSIGNMENTS=PKG_APACHE=apache24,PYTHON_VERSION_REQD=36
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
-ASSIGNMENTS=PYTHON_VERSION_REQD=26,RUBY_VERSION_REQD=193
+ASSIGNMENTS=PKG_APACHE=apache24,PYTHON_VERSION_REQD=36,RUBY_VERSION_REQD=23
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
-ASSIGNMENTS=PYTHON_VERSION_REQD=26,RUBY_VERSION_REQD=18
+ASSIGNMENTS=PKG_APACHE=apache24,PYTHON_VERSION_REQD=36,RUBY_VERSION_REQD=21
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
-ASSIGNMENTS=PYTHON_VERSION_REQD=26,RUBY_VERSION_REQD=21
+ASSIGNMENTS=PKG_APACHE=apache24,PYTHON_VERSION_REQD=35
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PKG_APACHE=apache24,PYTHON_VERSION_REQD=35,RUBY_VERSION_REQD=23
+PKGNAME=subversion-X
+PKGPATH=devel/subversion
+
+ASSIGNMENTS=PKG_APACHE=apache24,PYTHON_VERSION_REQD=35,RUBY_VERSION_REQD=21
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
@@ -422,11 +487,7 @@ ASSIGNMENTS=PKG_APACHE=apache24,PYTHON_VERSION_REQD=34
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
-ASSIGNMENTS=PKG_APACHE=apache24,PYTHON_VERSION_REQD=34,RUBY_VERSION_REQD=193
-PKGNAME=subversion-X
-PKGPATH=devel/subversion
-
-ASSIGNMENTS=PKG_APACHE=apache24,PYTHON_VERSION_REQD=34,RUBY_VERSION_REQD=18
+ASSIGNMENTS=PKG_APACHE=apache24,PYTHON_VERSION_REQD=34,RUBY_VERSION_REQD=23
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
@@ -434,31 +495,11 @@ ASSIGNMENTS=PKG_APACHE=apache24,PYTHON_VERSION_REQD=34,RUBY_VERSION_REQD=21
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
-ASSIGNMENTS=PKG_APACHE=apache24,PYTHON_VERSION_REQD=33
-PKGNAME=subversion-X
-PKGPATH=devel/subversion
-
-ASSIGNMENTS=PKG_APACHE=apache24,PYTHON_VERSION_REQD=33,RUBY_VERSION_REQD=193
-PKGNAME=subversion-X
-PKGPATH=devel/subversion
-
-ASSIGNMENTS=PKG_APACHE=apache24,PYTHON_VERSION_REQD=33,RUBY_VERSION_REQD=18
-PKGNAME=subversion-X
-PKGPATH=devel/subversion
-
-ASSIGNMENTS=PKG_APACHE=apache24,PYTHON_VERSION_REQD=33,RUBY_VERSION_REQD=21
-PKGNAME=subversion-X
-PKGPATH=devel/subversion
-
 ASSIGNMENTS=PKG_APACHE=apache24
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
-ASSIGNMENTS=PKG_APACHE=apache24,RUBY_VERSION_REQD=193
-PKGNAME=subversion-X
-PKGPATH=devel/subversion
-
-ASSIGNMENTS=PKG_APACHE=apache24,RUBY_VERSION_REQD=18
+ASSIGNMENTS=PKG_APACHE=apache24,RUBY_VERSION_REQD=23
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
@@ -466,53 +507,20 @@ ASSIGNMENTS=PKG_APACHE=apache24,RUBY_VERSION_REQD=21
 PKGNAME=subversion-X
 PKGPATH=devel/subversion
 
-ASSIGNMENTS=PKG_APACHE=apache24,PYTHON_VERSION_REQD=26
-PKGNAME=subversion-X
-PKGPATH=devel/subversion
-
-ASSIGNMENTS=PKG_APACHE=apache24,PYTHON_VERSION_REQD=26,RUBY_VERSION_REQD=193
-PKGNAME=subversion-X
-PKGPATH=devel/subversion
-
-ASSIGNMENTS=PKG_APACHE=apache24,PYTHON_VERSION_REQD=26,RUBY_VERSION_REQD=18
-PKGNAME=subversion-X
-PKGPATH=devel/subversion
-
-ASSIGNMENTS=PKG_APACHE=apache24,PYTHON_VERSION_REQD=26,RUBY_VERSION_REQD=21
-PKGNAME=subversion-X
-PKGPATH=devel/subversion
-
-'
-
-pkg_src_summary -m -f PKGNAME,PKGPATH www/ap-php:PHP_VERSION_REQD=53 |
-normalize_version |
-cmp 'pkg_src_summary #22.3' \
-'ASSIGNMENTS=PHP_VERSION_REQD=53
-PKGNAME=ap22-php53-X
-PKGPATH=www/ap-php
-
-ASSIGNMENTS=PHP_VERSION_REQD=53,PKG_APACHE=apache24
-PKGNAME=ap24-php53-X
-PKGPATH=www/ap-php
-
 '
 
 pkg_src_summary -m -f PKGNAME,PKGPATH www/ap-php:PKG_APACHE=apache22 |
 normalize_version |
 cmp 'pkg_src_summary #22.2' \
-'PKGNAME=ap22-php54-X
+'PKGNAME=ap22-php56-X
 PKGPATH=www/ap-php
 
-ASSIGNMENTS=PHP_VERSION_REQD=55
-PKGNAME=ap22-php55-X
+ASSIGNMENTS=PHP_VERSION_REQD=70
+PKGNAME=ap22-php70-X
 PKGPATH=www/ap-php
 
-ASSIGNMENTS=PHP_VERSION_REQD=56
-PKGNAME=ap22-php56-X
-PKGPATH=www/ap-php
-
-ASSIGNMENTS=PHP_VERSION_REQD=53
-PKGNAME=ap22-php53-X
+ASSIGNMENTS=PHP_VERSION_REQD=71
+PKGNAME=ap22-php71-X
 PKGPATH=www/ap-php
 
 '
@@ -520,35 +528,27 @@ PKGPATH=www/ap-php
 pkg_src_summary -m -f PKGNAME,PKGPATH www/ap-php |
 normalize_version |
 cmp 'pkg_src_summary #22.1' \
-'PKGNAME=ap22-php54-X
+'PKGNAME=ap22-php56-X
 PKGPATH=www/ap-php
 
-ASSIGNMENTS=PHP_VERSION_REQD=55
-PKGNAME=ap22-php55-X
+ASSIGNMENTS=PHP_VERSION_REQD=70
+PKGNAME=ap22-php70-X
 PKGPATH=www/ap-php
 
-ASSIGNMENTS=PHP_VERSION_REQD=56
-PKGNAME=ap22-php56-X
-PKGPATH=www/ap-php
-
-ASSIGNMENTS=PHP_VERSION_REQD=53
-PKGNAME=ap22-php53-X
+ASSIGNMENTS=PHP_VERSION_REQD=71
+PKGNAME=ap22-php71-X
 PKGPATH=www/ap-php
 
 ASSIGNMENTS=PKG_APACHE=apache24
-PKGNAME=ap24-php54-X
-PKGPATH=www/ap-php
-
-ASSIGNMENTS=PKG_APACHE=apache24,PHP_VERSION_REQD=55
-PKGNAME=ap24-php55-X
-PKGPATH=www/ap-php
-
-ASSIGNMENTS=PKG_APACHE=apache24,PHP_VERSION_REQD=56
 PKGNAME=ap24-php56-X
 PKGPATH=www/ap-php
 
-ASSIGNMENTS=PKG_APACHE=apache24,PHP_VERSION_REQD=53
-PKGNAME=ap24-php53-X
+ASSIGNMENTS=PKG_APACHE=apache24,PHP_VERSION_REQD=70
+PKGNAME=ap24-php70-X
+PKGPATH=www/ap-php
+
+ASSIGNMENTS=PKG_APACHE=apache24,PHP_VERSION_REQD=71
+PKGNAME=ap24-php71-X
 PKGPATH=www/ap-php
 
 '
@@ -746,79 +746,79 @@ pkg_src_summary -m -fPKGNAME,PKGPATH www/ap2-python |
 normalize_version |
 grep -v DEPENDS |
 cmp 'pkg_src_summary #2' \
-'ASSIGNMENTS=PYTHON_VERSION_REQD=34
-PKGNAME=ap22-py34-python-X
+'ASSIGNMENTS=PYTHON_VERSION_REQD=36
+PKGNAME=ap22-py36-python-X
 PKGPATH=www/ap2-python
 
-ASSIGNMENTS=PYTHON_VERSION_REQD=33
-PKGNAME=ap22-py33-python-X
+ASSIGNMENTS=PYTHON_VERSION_REQD=35
+PKGNAME=ap22-py35-python-X
+PKGPATH=www/ap2-python
+
+ASSIGNMENTS=PYTHON_VERSION_REQD=34
+PKGNAME=ap22-py34-python-X
 PKGPATH=www/ap2-python
 
 PKGNAME=ap22-py27-python-X
 PKGPATH=www/ap2-python
 
-ASSIGNMENTS=PYTHON_VERSION_REQD=26
-PKGNAME=ap22-py26-python-X
+ASSIGNMENTS=PKG_APACHE=apache24,PYTHON_VERSION_REQD=36
+PKGNAME=ap24-py36-python-X
+PKGPATH=www/ap2-python
+
+ASSIGNMENTS=PKG_APACHE=apache24,PYTHON_VERSION_REQD=35
+PKGNAME=ap24-py35-python-X
 PKGPATH=www/ap2-python
 
 ASSIGNMENTS=PKG_APACHE=apache24,PYTHON_VERSION_REQD=34
 PKGNAME=ap24-py34-python-X
 PKGPATH=www/ap2-python
 
-ASSIGNMENTS=PKG_APACHE=apache24,PYTHON_VERSION_REQD=33
-PKGNAME=ap24-py33-python-X
-PKGPATH=www/ap2-python
-
 ASSIGNMENTS=PKG_APACHE=apache24
 PKGNAME=ap24-py27-python-X
 PKGPATH=www/ap2-python
 
-ASSIGNMENTS=PKG_APACHE=apache24,PYTHON_VERSION_REQD=26
-PKGNAME=ap24-py26-python-X
-PKGPATH=www/ap2-python
-
 '
 
 pkg_src_summary -m --fields PKGNAME,PKGPATH www/ap2-python:PKG_APACHE=apache22 |
 normalize_version |
 grep -v DEPENDS |
 cmp 'pkg_src_summary #3' \
-'ASSIGNMENTS=PYTHON_VERSION_REQD=34
+'ASSIGNMENTS=PYTHON_VERSION_REQD=36
+PKGNAME=ap22-py36-python-X
+PKGPATH=www/ap2-python
+
+ASSIGNMENTS=PYTHON_VERSION_REQD=35
+PKGNAME=ap22-py35-python-X
+PKGPATH=www/ap2-python
+
+ASSIGNMENTS=PYTHON_VERSION_REQD=34
 PKGNAME=ap22-py34-python-X
 PKGPATH=www/ap2-python
 
-ASSIGNMENTS=PYTHON_VERSION_REQD=33
-PKGNAME=ap22-py33-python-X
-PKGPATH=www/ap2-python
-
 PKGNAME=ap22-py27-python-X
 PKGPATH=www/ap2-python
 
-ASSIGNMENTS=PYTHON_VERSION_REQD=26
-PKGNAME=ap22-py26-python-X
-PKGPATH=www/ap2-python
-
 '
 
 pkg_src_summary -m --fields PKGNAME,PKGPATH www/ap2-python:PKG_APACHE=apache22 |
 normalize_version |
 grep -v DEPENDS |
 cmp 'pkg_src_summary #3.1' \
-'ASSIGNMENTS=PYTHON_VERSION_REQD=34
+'ASSIGNMENTS=PYTHON_VERSION_REQD=36
+PKGNAME=ap22-py36-python-X
+PKGPATH=www/ap2-python
+
+ASSIGNMENTS=PYTHON_VERSION_REQD=35
+PKGNAME=ap22-py35-python-X
+PKGPATH=www/ap2-python
+
+ASSIGNMENTS=PYTHON_VERSION_REQD=34
 PKGNAME=ap22-py34-python-X
 PKGPATH=www/ap2-python
 
-ASSIGNMENTS=PYTHON_VERSION_REQD=33
-PKGNAME=ap22-py33-python-X
-PKGPATH=www/ap2-python
-
 PKGNAME=ap22-py27-python-X
 PKGPATH=www/ap2-python
 
-ASSIGNMENTS=PYTHON_VERSION_REQD=26
-PKGNAME=ap22-py26-python-X
-PKGPATH=www/ap2-python
-
 '
 
 pkg_src_summary -m --fields='PKGNAME PKGPATH' www/ap2-python:PYTHON_VERSION_REQD=27 |
@@ -834,50 +834,48 @@ PKGPATH=www/ap2-python
 
 '
 
-pkg_src_summary -m --fields='PKGNAME PKGPATH' www/ap2-python:PYTHON_VERSION_REQD=26 |
+pkg_src_summary -m --fields='PKGNAME PKGPATH' www/ap2-python:PYTHON_VERSION_REQD=27 |
 normalize_version |
 grep -v DEPENDS |
 cmp 'pkg_src_summary #4.1' \
-'ASSIGNMENTS=PYTHON_VERSION_REQD=26
-PKGNAME=ap22-py26-python-X
+'PKGNAME=ap22-py27-python-X
 PKGPATH=www/ap2-python
 
-ASSIGNMENTS=PYTHON_VERSION_REQD=26,PKG_APACHE=apache24
-PKGNAME=ap24-py26-python-X
+ASSIGNMENTS=PKG_APACHE=apache24
+PKGNAME=ap24-py27-python-X
 PKGPATH=www/ap2-python
 
 '
 
 pkg_src_summary -m -f'PKGNAME PKGPATH' \
-   www/ap2-python:PYTHON_VERSION_REQD=26,PKG_APACHE=apache22 |
+   www/ap2-python:PYTHON_VERSION_REQD=27,PKG_APACHE=apache22 |
 normalize_version |
 grep -v DEPENDS |
 cmp 'pkg_src_summary #5' \
-'ASSIGNMENTS=PYTHON_VERSION_REQD=26
-PKGNAME=ap22-py26-python-X
+'PKGNAME=ap22-py27-python-X
 PKGPATH=www/ap2-python
 
 '
 
 pkg_src_summary -Af PKGNAME,PKGPATH \
-   graphics/py-cairo:PYTHON_VERSION_REQD=26 |
-pkg_grep_summary -s PKGBASE 'python26' |
+   graphics/py-cairo:PYTHON_VERSION_REQD=27 |
+pkg_grep_summary -s PKGBASE 'python27' |
 awk -F= '$1 !~ /DEPENDS/' |
 normalize_version |
 cmp 'pkg_src_summary #6' \
-'PKGNAME=python26-X
-PKGPATH=lang/python26
+'PKGNAME=python27-X
+PKGPATH=lang/python27
 
 '
 
 pkg_src_summary -A -fPKGNAME,PKGPATH \
-   graphics/py-cairo:PYTHON_VERSION_REQD=26 |
-pkg_grep_summary -s PKGBASE 'python26' |
+   graphics/py-cairo:PYTHON_VERSION_REQD=27 |
+pkg_grep_summary -s PKGBASE 'python27' |
 awk -F= '$1 !~ /DEPENDS/' |
 normalize_version |
 cmp 'pkg_src_summary #7' \
-'PKGNAME=python26-X
-PKGPATH=lang/python26
+'PKGNAME=python27-X
+PKGPATH=lang/python27
 
 '
 
@@ -889,19 +887,21 @@ cmp 'pkg_src_summary #8' \
 'PKGNAME=py27-cairo-X
 PKGPATH=graphics/py-cairo
 
-ASSIGNMENTS=PYTHON_VERSION_REQD=26
-PKGNAME=py26-cairo-X
-PKGPATH=graphics/py-cairo
-
 PKGNAME=cairo-X
 PKGPATH=graphics/cairo
 
-PKGNAME=python26-X
-PKGPATH=lang/python26
-
 PKGNAME=python27-X
 PKGPATH=lang/python27
 
+PKGNAME=python36-X
+PKGPATH=lang/python36
+
+PKGNAME=python35-X
+PKGPATH=lang/python35
+
+PKGNAME=python34-X
+PKGPATH=lang/python34
+
 '
 
 pkg_src_summary -f PKGNAME --add-fields 'PKGPATH MAINTAINER' x11/xxkb |
@@ -998,3 +998,5 @@ cmp 'pkg_src_summary #19' \
 PKGPATH=devel/bmake
 
 '
+
+fi # test -d PKGSRCDIR
